Index: sdk/lib/_internal/compiler/implementation/lib/core_patch.dart |
diff --git a/sdk/lib/_internal/compiler/implementation/lib/core_patch.dart b/sdk/lib/_internal/compiler/implementation/lib/core_patch.dart |
index 1790162a331bf9fccad9096e9f7248446992d8cf..d4c2f9098217f8f9ef04c18399430a0d50ce2b8d 100644 |
--- a/sdk/lib/_internal/compiler/implementation/lib/core_patch.dart |
+++ b/sdk/lib/_internal/compiler/implementation/lib/core_patch.dart |
@@ -95,23 +95,23 @@ patch class Error { |
} |
-// Patch for Date implementation. |
-patch class _DateImpl { |
- patch _DateImpl(int year, |
- int month, |
- int day, |
- int hour, |
- int minute, |
- int second, |
- int millisecond, |
- bool isUtc) |
+// Patch for DateTime implementation. |
+patch class DateTime { |
+ patch DateTime._internal(int year, |
+ int month, |
+ int day, |
+ int hour, |
+ int minute, |
+ int second, |
+ int millisecond, |
+ bool isUtc) |
: this.isUtc = checkNull(isUtc), |
millisecondsSinceEpoch = Primitives.valueFromDecomposedDate( |
year, month, day, hour, minute, second, millisecond, isUtc) { |
Primitives.lazyAsJsDate(this); |
} |
- patch _DateImpl.now() |
+ patch DateTime._now() |
: isUtc = false, |
millisecondsSinceEpoch = Primitives.dateNow() { |
Primitives.lazyAsJsDate(this); |